#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 monadplus
version:              1.4.3
visibility:           public
id:                   monadplus-1.4.3-3Sy4U611IqM1LG7pOKeklQ
key:                  monadplus-1.4.3-3Sy4U611IqM1LG7pOKeklQ
license:              BSD-3-Clause
maintainer:           Hans Hoglund <hans@hanshoglund.se>
author:               Hans Hoglund
synopsis:             Haskell98 partial maps and filters over MonadPlus. 
description:
    Filtering and folding over arbitrary `MonadPlus` instances.
    This package generalizes many common stream operations such as
    `filter`, `catMaybes` etc.

category:             Control
abi:                  670c2fa07c87d26ef3f0e69dbdfd1b4e
exposed:              True
exposed-modules:      Control.Applicative.Alternative Control.Monad.Plus
import-dirs:          /usr/lib/ghc-9.6.6/site-local/monadplus-1.4.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/monadplus-1.4.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/monadplus-1.4.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monadplus
hs-libraries:         HSmonadplus-1.4.3-3Sy4U611IqM1LG7pOKeklQ
depends:              base-4.18.2.1
haddock-interfaces:   /usr/share/doc/haskell-monadplus/html/monadplus.haddock
haddock-html:         /usr/share/doc/haskell-monadplus/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

